@@ -2522,6 +2522,7 @@ class VariableOsInstallFormatSingleSet(Variable):
     opt = ["--format"]
     untrusted = True
     value = "off"
+    check_after = ["cl_target_fs"]
 
     def init(self):
         self.label = _("Format the USB Flash")
@@ -2529,7 +2530,8 @@ class VariableOsInstallFormatSingleSet(Variable):
 
     def must_be_formatted(self, dev):
         fs = self.select('os_disk_format', os_disk_dev=dev, limit=1)
-        if fs != "vfat":
+        new_fs = self.Get('cl_target_fs')
+        if fs != new_fs:
             return True
         return False
 
@@ -2549,8 +2551,8 @@ class VariableOsInstallFormatSingleSet(Variable):
                       "contains the current system"))
         else:
             if self.must_be_formatted(dev):
-                raise VariableError(
-                    _("{device} must be formatted").format(device=dev))
+                self.value = 'on'
+                value = 'on'
             if dev:
                 try:
                     with FlashDistributive(dev) as f:
